*===================== Program: IQI_PROV_OBSERVED.SAS =========================;
*
*        Title:  PROVIDER LEVEL OBSERVED RATES FOR AHRQ 
*                INPATIENT QUALITY INDICATORS
*  Description:
*     CALCULATES OBSERVED RATES FOR PROVIDER LEVEL INPATIENT QUALITY INDICATORS
*     USING OUTPUT FROM IQI_ALL_MEASURES.SAS.
*     OUTPUT STRATIFIED BY HOSPID, AGECAT, SEXCAT, PAYCAT AND RACECAT.
*	  VARIABLES CREATED BY THIS PROGRAM ARE PPQIxx and OPIQxx	
*
*                     >>>  AHRQ QI ICD-10  VERSION 6.0.1 <<<
*		                >>> VERSION DATE SEPT, 2016 <<<
*==============================================================================;
*PATHNAME specifies the location of the IQI folder which includes 
          Programs, SASdata, and Macros subfolders;
%LET PATHNAME=c:\pathname;                         *<===USER MUST modify; 
filename CONTROL "&PATHNAME.\IQI\Programs\IQI_ALL_CONTROL.SAS"; 

%include CONTROL;

 title2 'PROGRAM: IQI_PROV_OBSERVED.SAS';
 title3 'AHRQ INPATIENT QUALITY INDICATORS: CALCULATE OBSERVED PROVIDER LEVEL RATES';
 
 * -------------------------------------------------------------- ;
* --- INPATIENT QUALITY INDICATOR (IQI) NAMING CONVENTION:   --- ;
* --- THE FIRST LETTER IDENTIFIES THE INPATIENT QUALITY      --- ;
* --- INDICATOR AS ONE OF THE FOLLOWING:
                (T) NUMERATOR ("TOP") - FROM PDI_ALL_MEASURES
                (P) POPULATION ("POP")
                (O) OBSERVED RATES
* --- THE SECOND LETTER IDENTIFIES THE IQI AS A PROVIDER (P) --- ;
* --- OR AN AREA (A) LEVEL INDICATOR.  THE                   --- ;
* --- NEXT TWO CHARACTERS ARE ALWAYS 'IQ'. THE LAST TWO      --- ;
* --- DIGITS ARE THE INDICATOR NUMBER (WITHIN THAT SUBTYPE). --- ;
* -------------------------------------------------------------- ;

* ----------------------------------------------------------------- ;
* --- PROVIDER LEVEL MEANS ON IQI_ALL_MEASURES OUTPUT DATA FILE  ---;
* --- THE TPIQxx VARIABLE IS CREATED IN THE MEAUSURES PROGRAM AND --;
* --- USED TO CALCULATE PPIQxx and the OPIQxx variables          ---; 
 * ----------------------------------------------------------------- ;

 * sumwgt is unassigned using default of weight = 1;
 proc   Summary data=OUTMSR.&OUTFILE_MEAS.;
 class  HOSPID AGECAT SEXCAT PAYCAT RACECAT;
 var    TPIQ01  TPIQ02 TPIQ02A  TPIQ02B TPIQ04 TPIQ04A TPIQ04B TPIQ04C TPIQ04D
        TPIQ05-TPIQ09   TPIQ09A TPIQ09B TPIQ11 TPIQ11A TPIQ11B TPIQ11C TPIQ11D  TPIQ12-TPIQ17
		TPIQ17A TPIQ17B TPIQ17C TPIQ18-TPIQ25  TPIQ30-TPIQ34;
 output out=&OUTFILE_PROVOBS.
        sum(TPIQ01  TPIQ02 TPIQ02A TPIQ02B TPIQ04 TPIQ04A TPIQ04B TPIQ04C TPIQ04D TPIQ05-TPIQ09
            TPIQ09A TPIQ09B TPIQ11 TPIQ11A TPIQ11B TPIQ11C TPIQ11D TPIQ12-TPIQ17
            TPIQ17A TPIQ17B TPIQ17C TPIQ18-TPIQ25 TPIQ30-TPIQ34)=
        sumwgt(TPIQ08  TPIQ09  TPIQ09A TPIQ09B TPIQ11 TPIQ11A TPIQ11B TPIQ11C TPIQ11D TPIQ12-TPIQ17
               TPIQ17A TPIQ17B TPIQ17C TPIQ18-TPIQ25 TPIQ30-TPIQ34)= PPIQ08 PPIQ09 PPIQ09A PPIQ09B PPIQ11 PPIQ11A PPIQ11B PPIQ11C PPIQ11D
                                                                     PPIQ12-PPIQ17 PPIQ17A PPIQ17B PPIQ17C PPIQ18-PPIQ25 PPIQ30-PPIQ34
        mean  (TPIQ08 TPIQ09 TPIQ09A TPIQ09B TPIQ11 TPIQ11A TPIQ11B TPIQ11C TPIQ11D TPIQ12-TPIQ17
               TPIQ17A TPIQ17B TPIQ17C TPIQ18-TPIQ25 TPIQ30-TPIQ34)= OPIQ08 OPIQ09 OPIQ09A OPIQ09B OPIQ11 OPIQ11A OPIQ11B OPIQ11C OPIQ11D 
                                                                     OPIQ12-OPIQ17 OPIQ17A OPIQ17B OPIQ17C OPIQ18-OPIQ25 OPIQ30-OPIQ34 ;
 run;


 proc Sort data=&OUTFILE_PROVOBS.;
 BY HOSPID AGECAT SEXCAT PAYCAT RACECAT;
 run;

 data OUTPOBS.&OUTFILE_PROVOBS.;
   set &OUTFILE_PROVOBS. (where=(_TYPE_ &TYPELVLP));
    
 Label
 TPIQ01   ='IQI 01 Esophageal Resection Volume (Numerator)'
 TPIQ02   ='IQI 02 Pancreatic Resection Volume (Numerator)'
 TPIQ02A  ='IQI 02 Pancreatic Resection Volume Stratum A (Numerator)'
 TPIQ02B  ='IQI 02 Pancreatic Resection Volume Stratum B (Numerator)'
 TPIQ04   ='IQI 04 Abdominal Aortic Aneurysm (AAA) Repair Volume (Numerator)'
 TPIQ04A  ='IQI 04 Abdominal Aortic Aneurysm (AAA) Repair Volume Stratum A: Open repair of ruptured AAA (Numerator)'
 TPIQ04B  ='IQI 04 Abdominal Aortic Aneurysm (AAA) Repair Volume Stratum B: Open repair of unruptured AAA (Numerator)'
 TPIQ04C  ='IQI 04 Abdominal Aortic Aneurysm (AAA) Repair Volume Stratum C: Endovascular repair of ruptured AAA (Numerator)'
 TPIQ04D  ='IQI 04 Abdominal Aortic Aneurysm (AAA) Repair Volume Stratum D: Endovascular repair of unruptured AAA (Numerator)'
 TPIQ05   ='IQI 05 Coronary Artery Bypass Graft (CABG) Volume (Numerator)'
 TPIQ06   ='IQI 06 Percutaneous Coronary Intervention (PCI) Volume (Numerator)'
 TPIQ07   ='IQI 07 Carotid Endarterectomy Volume (Numerator)'
 TPIQ08   ='IQI 08 Esophageal Resection Mortality Rate (Numerator)'
 TPIQ09   ='IQI 09 Pancreatic Resection Mortality Rate (Numerator)'
 TPIQ09A  ='IQI 09 Pancreatic Resection Mortality Rate Stratum A: Presence of Pancreatic Cancer Diagnosis (Numerator)'
 TPIQ09B  ='IQI 09 Pancreatic Resection Mortality Rate Stratum B: Absence of Pancreatic Cancer Diagnosis (Numerator)'
 TPIQ11   ='IQI 11 Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate (Numerator)'
 TPIQ11A  ='IQI 11 Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate Stratum A: Open repair of ruptured AAA ((Numerator)'
 TPIQ11B  ='IQI 11 Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate Stratum B: Open repair of unruptured AAA (Numerator)'
 TPIQ11C  ='IQI 11 Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate Stratum C: Endovascular repair of ruptured AAA (Numerator)'
 TPIQ11D  ='IQI 11 Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate Stratum D: Endovascular repair of unruptured AAA (Numerator)'
 TPIQ12   ='IQI 12 Coronary Artery Bypass Graft (CABG) Mortality Rate (Numerator)'
 TPIQ13   ='IQI 13 Craniotomy Mortality Rate (Numerator)'
 TPIQ14   ='IQI 14 Hip Replacement Mortality Rate (Numerator)'
 TPIQ15   ='IQI 15 Acute Myocardial Infarction (AMI) Mortality Rate (Numerator)'
 TPIQ16   ='IQI 16 Heart Failure Mortality Rate (Numerator)'
 TPIQ17   ='IQI 17 Acute Stroke Mortality Rate (Numerator)'
 TPIQ17A  ='IQI 17 Acute Stroke Mortality Rate Stratum A: Subarachnoid hemorrhage (Numerator)'
 TPIQ17B  ='IQI 17 Acute Stroke Mortality Rate Stratum B: Intracerebral hemorrhage (Numerator)'
 TPIQ17C  ='IQI 17 Acute Stroke Mortality Rate Stratum C: Ischemic stroke (Numerator)'
 TPIQ18   ='IQI 18 Gastrointestinal Hemorrhage Mortality Rate (Numerator)'
 TPIQ19   ='IQI 19 Hip Fracture Mortality Rate (Numerator)'
 TPIQ20   ='IQI 20 Pneumonia Mortality Rate (Numerator)'
 TPIQ21   ='IQI 21 Cesarean Delivery Rate, Uncomplicated (Numerator)'
 TPIQ22   ='IQI 22 Vaginal Birth After Cesarean (VBAC) Delivery Rate, Uncomplicated (Numerator)'
 TPIQ23   ='IQI 23 Laparoscopic Cholecystectomy Rate (Numerator)'
 TPIQ24   ='IQI 24 Incidental Appendectomy in the Elderly Rate (Numerator)'
 TPIQ25   ='IQI 25 Bilateral Cardiac Catheterization Rate (Numerator)'
 TPIQ30   ='IQI 30 Percutaneous Coronary Intervention (PCI) Mortality Rate (Numerator)'
 TPIQ31   ='IQI 31 Carotid Endarterectomy Mortality Rate (Numerator)'
 TPIQ32   ='IQI 32 Acute Myocardial Infarction (AMI) Mortality Rate, Without Transfer Cases (Numerator)'
 TPIQ33   ='IQI 33 Primary Cesarean Delivery Rate, Uncomplicated (Numerator)'
 TPIQ34   ='IQI 34 Vaginal Birth After Cesarean (VBAC) Rate, All (Numerator)'

 PPIQ08   ='IQI 08 Esophageal Resection Mortality Rate (Population)'
 PPIQ09   ='IQI 09 Pancreatic Resection Mortality Rate (Population)'
 PPIQ09A  ='IQI 09 Pancreatic Resection Mortality Rate Stratum A: Presence of Pancreatic Cancer Diagnosis (Population)'
 PPIQ09B  ='IQI 09 Pancreatic Resection Mortality Rate Stratum B: Absence of Pancreatic Cancer Diagnosis (Population)'
 PPIQ11   ='IQI 11 Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate (Population)'
 PPIQ11A  ='IQI 11 Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate Stratum A: Open repair of ruptured AAA (Population)'
 PPIQ11B  ='IQI 11 Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate Stratum B: Open repair of unruptured AAA (Population)'
 PPIQ11C  ='IQI 11 Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate Stratum C: Endovascular repair of ruptured AAA (Population)'
 PPIQ11D  ='IQI 11 Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate Stratum D: Endovascular repair of unruptured AAA (Population)'
 PPIQ12   ='IQI 12 Coronary Artery Bypass Graft (CABG) Mortality Rate (Population)'
 PPIQ13   ='IQI 13 Craniotomy Mortality Rate (Population)'
 PPIQ14   ='IQI 14 Hip Replacement Mortality Rate (Population)'
 PPIQ15   ='IQI 15 Acute Myocardial Infarction (AMI) Mortality Rate (Population)'
 PPIQ16   ='IQI 16 Heart Failure Mortality Rate (Population)'
 PPIQ17   ='IQI 17 Acute Stroke Mortality Rate (Population)'
 PPIQ17A  ='IQI 17 Acute Stroke Mortality Rate Stratum A: Subarachnoid hemorrhage (Population)'
 PPIQ17B  ='IQI 17 Acute Stroke Mortality Rate Stratum B: Intracerebral hemorrhage (Population)'
 PPIQ17C  ='IQI 17 Acute Stroke Mortality Rate Stratum C: Ischemic stroke (Population)'
 PPIQ18   ='IQI 18 Gastrointestinal Hemorrhage Mortality Rate (Population)'
 PPIQ19   ='IQI 19 Hip Fracture Mortality Rate (Population)'
 PPIQ20   ='IQI 20 Pneumonia Mortality Rate (Population)'
 PPIQ21   ='IQI 21 Cesarean Delivery Rate, Uncomplicated (Population)'
 PPIQ22   ='IQI 22 Vaginal Birth After Cesarean (VBAC) Delivery Rate, Uncomplicated (Population)'
 PPIQ23   ='IQI 23 Laparoscopic Cholecystectomy Rate (Population)'
 PPIQ24   ='IQI 24 Incidental Appendectomy in the Elderly Rate (Population)'
 PPIQ25   ='IQI 25 Bilateral Cardiac Catheterization Rate (Population)'
 PPIQ30   ='IQI 30 Percutaneous Coronary Intervention (PCI) Mortality Rate (Population)'
 PPIQ31   ='IQI 31 Carotid Endarterectomy Mortality Rate (Population)'
 PPIQ32   ='IQI 32 Acute Myocardial Infarction (AMI) Mortality Rate, Without Transfer Cases (Population)'
 PPIQ33   ='IQI 33 Primary Cesarean Delivery Rate, Uncomplicated (Population)'
 PPIQ34   ='IQI 34 Vaginal Birth After Cesarean (VBAC) Rate, All (Population)'

 OPIQ08   ='IQI 08 Esophageal Resection Mortality Rate (Observed)'
 OPIQ09   ='IQI 09 Pancreatic Resection Mortality Rate (Observed)'
 OPIQ09A  ='IQI 09 Pancreatic Resection Mortality Rate Stratum A: Presence of Pancreatic Cancer Diagnosis (Observed)'
 OPIQ09B  ='IQI 09 Pancreatic Resection Mortality Rate Stratum B: Absence of Pancreatic Cancer Diagnosis (Observed)'
 OPIQ11   ='IQI 11 Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate (Observed)'
 OPIQ11A  ='IQI 11 Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate Stratum A: Open repair of ruptured AAA (Observed)'
 OPIQ11B  ='IQI 11 Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate Stratum B: Open repair of unruptured AAA (Observed)'
 OPIQ11C  ='IQI 11 Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate Stratum C: Endovascular repair of ruptured AAA (Observed)'
 OPIQ11D  ='IQI 11 Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate Stratum D: Endovascular repair of unruptured AAA (Observed)'
 OPIQ12   ='IQI 12 Coronary Artery Bypass Graft (CABG) Mortality Rate (Observed)'
 OPIQ13   ='IQI 13 Craniotomy Mortality Rate (Observed)'
 OPIQ14   ='IQI 14 Hip Replacement Mortality Rate (Observed)'
 OPIQ15   ='IQI 15 Acute Myocardial Infarction (AMI) Mortality Rate (Observed)'
 OPIQ16   ='IQI 16 Heart Failure Mortality Rate (Observed)'
 OPIQ17   ='IQI 17 Acute Stroke Mortality Rate (Observed)'
 OPIQ17A  ='IQI 17 Acute Stroke Mortality Rate Stratum A: Subarachnoid hemorrhage (Observed)'
 OPIQ17B  ='IQI 17 Acute Stroke Mortality Rate Stratum B: Intracerebral hemorrhage (Observed)'
 OPIQ17C  ='IQI 17 Acute Stroke Mortality Rate Stratum C: Ischemic stroke (Observed)'
 OPIQ18   ='IQI 18 Gastrointestinal Hemorrhage Mortality Rate (Observed)'
 OPIQ19   ='IQI 19 Hip Fracture Mortality Rate (Observed)'
 OPIQ20   ='IQI 20 Pneumonia Mortality Rate (Observed)'
 OPIQ21   ='IQI 21 Cesarean Delivery Rate, Uncomplicated (Observed)'
 OPIQ22   ='IQI 22 Vaginal Birth After Cesarean (VBAC) Delivery Rate, Uncomplicated (Observed)'
 OPIQ23   ='IQI 23 Laparoscopic Cholecystectomy Rate (Observed)'
 OPIQ24   ='IQI 24 Incidental Appendectomy in the Elderly Rate (Observed)'
 OPIQ25   ='IQI 25 Bilateral Cardiac Catheterization Rate (Observed)'
 OPIQ30   ='IQI 30 Percutaneous Coronary Intervention (PCI) Mortality Rate (Observed)'
 OPIQ31   ='IQI 31 Carotid Endarterectomy Mortality Rate (Observed)'
 OPIQ32   ='IQI 32 Acute Myocardial Infarction (AMI) Mortality Rate, Without Transfer Cases (Observed)'
 OPIQ33   ='IQI 33 Primary Cesarean Delivery Rate, Uncomplicated (Observed)'
 OPIQ34   ='IQI 34 Vaginal Birth After Cesarean (VBAC) Rate, All (Observed)'
 _TYPE_   ='STRATIFICATION LEVEL'
;
 drop _FREQ_ ;
run;

 * -------------------------------------------------------------- ;
 * --- CONTENTS AND MEANS OF PROVIDER OBSERVED MEANS FILE ------- ;
 * -------------------------------------------------------------- ;

 proc   Contents data=OUTPOBS.&OUTFILE_PROVOBS. position;
 run;


***----- TO PRINT VARIABLE LABLES COMMENT (DELETE) "NOLABELS" FROM PROC MEANS STATEMENTS -------***;
proc Means data=OUTPOBS.&OUTFILE_PROVOBS. (where=(_TYPE_ IN (16))) n nmiss min max sum nolabels;
   var TPIQ01  TPIQ02 TPIQ02A  TPIQ02B TPIQ04 TPIQ04A TPIQ04B TPIQ04C TPIQ04D
       TPIQ05-TPIQ09   TPIQ09A TPIQ09B TPIQ11 TPIQ11A TPIQ11B TPIQ11C TPIQ11D  TPIQ12-TPIQ17
	   TPIQ17A TPIQ17B TPIQ17C TPIQ18-TPIQ25  TPIQ30-TPIQ34;
   title  'SUMMARY OF INPATIENT QUALITY PROVIDER-LEVEL INDICATOR OVERALL NUMERATOR (SUM) WHEN _TYPE_=16';
run; quit;

proc Means data=OUTPOBS.&OUTFILE_PROVOBS. (where=(_TYPE_ IN (16))) n nmiss min max sum nolabels;
   var PPIQ08 PPIQ09 PPIQ09A PPIQ09B PPIQ11 PPIQ11A PPIQ11B PPIQ11C PPIQ11D
       PPIQ12-PPIQ17 PPIQ17A PPIQ17B PPIQ17C PPIQ18-PPIQ25 PPIQ30-PPIQ34;
   title  'SUMMARY OF INPATIENT QUALITY PROVIDER-LEVEL INDICATOR OVERALL DENOMINATOR (SUM) WHEN _TYPE_=16';
run; quit;

proc Means data=OUTPOBS.&OUTFILE_PROVOBS. (where=(_TYPE_ IN (16))) n nmiss min max mean nolabels;
   VAR OPIQ08 OPIQ09 OPIQ09A OPIQ09B OPIQ11 OPIQ11A OPIQ11B OPIQ11C OPIQ11D 
       OPIQ12-OPIQ17 OPIQ17A OPIQ17B OPIQ17C OPIQ18-OPIQ25 OPIQ30-OPIQ34;
   title  'SUMMARY OF INPATIENT QUALITY PROVIDER-LEVEL INDICATOR AVERAGE RATES(MEAN) WHEN _TYPE_=16';
run; quit;

 * -------------------------------------------------------- ;
 * --- PRINT PROVIDER OBSERVED MEANS FILE TO SAS OUTPUT --- ;
 * -------------------------------------------------------- ;

 %MACRO PRT2;

 %IF &PRINT. = 1 %THEN %DO;

 %MACRO PRT(IQ,TEXT,VOLUME);

 proc   PRINT data=OUTPOBS.&OUTFILE_PROVOBS. LABEL SPLIT='*';
 %IF &VOLUME=0 %THEN %DO;
 var    HOSPID AGECAT SEXCAT PAYCAT RACECAT TPIQ&IQ. PPIQ&IQ. OPIQ&IQ. ;
 label HOSPID  = "HOSPID"
       AGECAT  = "AGECAT"
       SEXCAT  = "SEXCAT"
       PAYCAT  = "PAYCAT"
       RACECAT = "RACECAT"
       TPIQ&IQ.   = "TPIQ&IQ.*(Numerator)"
       PPIQ&IQ.   = "PPIQ&IQ.*(Denominator)"
       OPIQ&IQ.   = "OPIQ&IQ.*(Observed)"
       ;
 format TPIQ&IQ. PPIQ&IQ. 13.0 OPIQ&IQ. 8.6;
 %END;
 %ELSE %DO;
 var    HOSPID AGECAT SEXCAT PAYCAT RACECAT TPIQ&IQ.  ;
 label HOSPID  = "HOSPID"
       AGECAT  = "AGECAT"
       SEXCAT  = "SEXCAT"
       PAYCAT  = "PAYCAT"
       RACECAT = "RACECAT"
       TPIQ&IQ.   = "TPIQ&IQ.*(Numerator)"
       ;
 format TPIQ&IQ. 13.0;
 %END;
 format AGECAT AGECAT.
        SEXCAT SEXCAT.
        PAYCAT PAYCAT.
        RACECAT RACECAT.
   ;
 title4 "Indicator &IQ.: &TEXT";
 run;

 %MEND PRT;

 %PRT(01, Esophageal Resection Volume,1);
 %PRT(02, Pancreatic Resection Volume,1);
 %PRT(02A, Pancreatic Resection Volume Stratum A,1);
 %PRT(02B, Pancreatic Resection Volume Stratum B,1);
 %PRT(04, Abdominal Aortic Aneurysm (AAA) Repair Volume,1);
 %PRT(04A, Abdominal Aortic Aneurysm (AAA) Repair Volume Stratum A,1);
 %PRT(04B, Abdominal Aortic Aneurysm (AAA) Repair Volume Stratum B,1);
 %PRT(04C, Abdominal Aortic Aneurysm (AAA) Repair Volume Stratum C,1);
 %PRT(04D, Abdominal Aortic Aneurysm (AAA) Repair Volume Stratum D,1);
 %PRT(05, Coronary Artery Bypass Graft (CABG) Volume,1); 
 %PRT(06, Percutaneous Coronary Intervention (PCI) Volume,1);
 %PRT(07, Carotid Endarterectomy Volume,1);
 %PRT(08, Esophageal Resection Mortality Rate,0);
 %PRT(09, Pancreatic Resection Mortality Rate,0)
 %PRT(09A, Pancreatic Resection Mortality Rate Stratum A,0);
 %PRT(09B, Pancreatic Resection Mortality Rate Stratum B,0)
 %PRT(11, Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate,0);
 %PRT(11A, Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate Stratum A,0);
 %PRT(11B, Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate Stratum B,0);
 %PRT(11C, Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate Stratum C,0);
 %PRT(11D, Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate Stratum D,0);
 %PRT(12, Coronary Artery Bypass Graft (CABG) Mortality Rate,0);
 %PRT(13, Craniotomy Mortality Rate,0);
 %PRT(14, Hip Replacement Mortality Rate,0);
 %PRT(15, Acute Myocardial Infarction (AMI) Mortality Rate,0);
 %PRT(16, Heart Failure Mortality Rate,0);
 %PRT(17, Acute Stroke Mortality Rate,0);
 %PRT(17A, Acute Stroke Mortality Rate Stratum A,0);
 %PRT(17B, Acute Stroke Mortality Rate Stratum B,0);
 %PRT(17C, Acute Stroke Mortality Rate Stratum C,0);
 %PRT(18, Gastrointestinal Hemorrhage Mortality Rate,0);
 %PRT(19, Hip Fracture Mortality Rate,0);
 %PRT(20, Pneumonia Mortality Rate,0);
 %PRT(21, %BQUOTE(Cesarean Delivery Rate, Uncomplicated),0);
 %PRT(22, %BQUOTE(Vaginal Birth After Cesarean (VBAC) Delivery Rate, Uncomplicated),0);
 %PRT(23, Laparoscopic Cholecystectomy Rate,0);
 %PRT(24, Incidental Appendectomy in the Elderly Rate,0);
 %PRT(25, Bilateral Cardiac Catheterization Rate,0);
 %PRT(30, Percutaneous Coronary Intervention (PCI) Mortality Rate,0);
 %PRT(31, Carotid Endarterectomy Mortality Rate,0);
 %PRT(32, %BQUOTE(Acute Myocardial Infarction (AMI) Mortality Rate, Without Transfer Cases),0);
 %PRT(33, %BQUOTE(Primary Cesarean Delivery Rate, Uncomplicated),0);
 %PRT(34, %BQUOTE(Vaginal Birth After Cesarean (VBAC) Rate, All),0);

 %END;

 %MEND PRT2;

 %PRT2;


 * -------------------------------------------------------------- ;
 * --- WRITE SAS OUTPUT DATA SET TO COMMA-DELIMITED TEXT FILE --- ;
 * --- FOR EXPORT INTO SPREADSHEETS ----------------------------- ;
 * -------------------------------------------------------------- ;

 %MACRO TEXTP1;
 %if &TXTPOBS. = 1  %then %do;
	%LET TYPEPRN  = %sysfunc(tranwrd(&TYPELVLP.,%str(,),_));
	%LET TYPEPRN2  = %sysfunc(compress(&TYPEPRN.,'(IN )'));
	%let IQCSVREF = %sysfunc(pathname(IQTXTPOB));
	%let IQCSVRF2 =  %sysfunc(tranwrd(&IQCSVREF.,.,_&TYPEPRN2..));
	 data _NULL_;
 set OUTPOBS.&OUTFILE_PROVOBS.;
 file  "&IQCSVRF2." lrecl=2000 ;
 if _N_=1 then do;
 put "Hosp Id" "," "Age"  "," "Sex"  "," "Payer" "," "Race"  "," "Type" ","
 "TPIQ01"  "," "TPIQ02"  "," "TPIQ02A" "," "TPIQ02B" "," "TPIQ04"  ","  
 "TPIQ04A" "," "TPIQ04B" "," "TPIQ04C" "," "TPIQ04D" ","  
 "TPIQ05"  "," "TPIQ06"  "," "TPIQ07"  "," "TPIQ08"  "," "TPIQ09"  ","
 "TPIQ09A" "," "TPIQ09B" "," "TPIQ11"  "," "TPIQ11A" "," "TPIQ11B" "," "TPIQ11C" "," "TPIQ11D" "," 
 "TPIQ12"  "," "TPIQ13"  "," "TPIQ14"  "," "TPIQ15"  "," "TPIQ16"  ","
 "TPIQ17"  "," "TPIQ17A" "," "TPIQ17B" "," "TPIQ17C" "," "TPIQ18"  "," 
 "TPIQ19"  "," "TPIQ20"  "," "TPIQ21"  "," "TPIQ22"  "," "TPIQ23"  "," 
 "TPIQ24"  "," "TPIQ25"  "," "TPIQ30"  "," "TPIQ31"  "," "TPIQ32"  "," 
 "TPIQ33"  "," "TPIQ34"  "," 
 
 "PPIQ08"  "," "PPIQ09"  "," "PPIQ09A" "," "PPIQ09B" "," "PPIQ11" "," 
 "PPIQ11A" "," "PPIQ11B" "," "PPIQ11C" "," "PPIQ11D" "," "PPIQ12" ","
 "PPIQ13"  "," "PPIQ14"  "," "PPIQ15"  "," "PPIQ16"  "," 
 "PPIQ17"  "," "PPIQ17A" "," "PPIQ17B" "," "PPIQ17C" "," "PPIQ18"  "," 
 "PPIQ19"  "," "PPIQ20"  "," "PPIQ21"  "," "PPIQ22"  "," "PPIQ23"  "," 
 "PPIQ24" ","  "PPIQ25"  "," "PPIQ30"  "," "PPIQ31"  "," "PPIQ32" "," 
 "PPIQ33"  "," "PPIQ34"  "," 

 "OPIQ08"  "," "OPIQ09"  "," "OPIQ09A" "," "OPIQ09B" "," "OPIQ11"  "," 
 "OPIQ11A" "," "OPIQ11B" "," "OPIQ11C" "," "OPIQ11D" "," "OPIQ12"  ","
 "OPIQ13"  "," "OPIQ14"  "," "OPIQ15"  "," "OPIQ16"  "," "OPIQ17"  "," 
 "OPIQ17A" "," "OPIQ17B" "," "OPIQ17C" "," "OPIQ18"  "," "OPIQ19"  "," 
 "OPIQ20" ","  "OPIQ21"  "," "OPIQ22"  "," "OPIQ23"  "," "OPIQ24"  ","
 "OPIQ25"  "," "OPIQ30"  "," "OPIQ31"  "," "OPIQ32"  "," 
 "OPIQ33"  "," "OPIQ34" 
 ;

 end;

 put HOSPID 13. "," AGECAT 3.  "," SEXCAT 3. "," PAYCAT 3. "," RACECAT 3. "," _TYPE_ 2.  ","
 (TPIQ01 TPIQ02 TPIQ02A TPIQ02B TPIQ04 TPIQ04A TPIQ04B TPIQ04C TPIQ04D TPIQ05-TPIQ08 TPIQ09 TPIQ09A TPIQ09B 
  TPIQ11 TPIQ11A TPIQ11B TPIQ11C TPIQ11D TPIQ12-TPIQ17 TPIQ17A TPIQ17B TPIQ17C 
  TPIQ18-TPIQ25 TPIQ30-TPIQ34) (7.0 ",")
 ","
 (PPIQ08 PPIQ09 PPIQ09A PPIQ09B PPIQ11 PPIQ11A PPIQ11B PPIQ11C PPIQ11D PPIQ12-PPIQ17 PPIQ17A PPIQ17B PPIQ17C PPIQ18-PPIQ25 PPIQ30-PPIQ34) (13.2 ",")
 ","
 (OPIQ08 OPIQ09 OPIQ09A OPIQ09B OPIQ11 OPIQ11A OPIQ11B OPIQ11C OPIQ11D OPIQ12-OPIQ17 OPIQ17A OPIQ17B OPIQ17C  OPIQ18-OPIQ25 OPIQ30-OPIQ34) (12.10 ",")
 ;
 run;

 %END;

 %MEND TEXTP1;

 %TEXTP1;
