 * ------------------------------------------------------------------- ;
 * --DIAGNOSIS AND PROCEDURE MACROS for PQI09 module ICD-10 V6.0.1 --- ;
 * ------------------------------------------------------------------- ;

*DESCRIPTION: Assigns diagnosis and procedure macros called by other SAS programs
              The user does not need to open.;

 /*Macro to add PRDAY fields onto input statement based on Control file input.*/
 %MACRO ADDPRDAY; 
    %IF &PRDAY EQ 1 %THEN PRDAY1-PRDAY&NPR. ;
 %MEND;

 /*Macro to compare all discharge diagnosis codes against format.*/
 %MACRO MDX(FMT);

 (%DO I = 1 %TO &NDX.-1;
  (PUT(DX&I.,&FMT.) = '1') OR
  %END;
  (PUT(DX&NDX.,&FMT.) = '1'))

 %MEND;

 /*Macro to compare discharge primary diagnosis code against format.*/
 %MACRO MDX1(FMT);

 (PUT(DX1,&FMT.) = '1')

 %MEND;

  /*Macro to compare discharge secondary diagnosis codes against format.*/
 %MACRO MDX2(FMT);

 (%DO I = 2 %TO &NDX.-1;
  (PUT(DX&I.,&FMT.) = '1') OR
  %END;
  (PUT(DX&NDX.,&FMT.) = '1'))

 %MEND;
/*Macro to determine if measure format diagnosis is included in any secondary discharge diagnosis code as not present on admission.*/
 %MACRO MDX2Q1(FMT);

 (%DO I = 2 %TO &NDX.-1;
  (PUT(DX&I.,$poaxmpt.)='0' AND PUT(DX&I.,&FMT.) = '1' AND DXPOA&I. IN ('N','U',' ','E','1','X')) OR
  %END;
  (PUT(DX&NDX.,$poaxmpt.)='0' AND PUT(DX&NDX.,&FMT.) = '1' AND DXPOA&NDX. IN ('N','U',' ','E','1','X')))

 %MEND;
/*Macro to determine if measure format diagnosis is included in any secondary discharge diagnosis code as present on admission.*/
 %MACRO MDX2Q2(FMT);

 (%DO I = 2 %TO &NDX.-1;
  (PUT(DX&I.,$poaxmpt.)='0' AND PUT(DX&I.,&FMT.) = '1' AND DXPOA&I. IN ('Y','W')) OR
  (PUT(DX&I.,$poaxmpt.)='1' AND PUT(DX&I.,&FMT.) = '1') OR
  %END;
  (PUT(DX&NDX.,$poaxmpt.)='0' AND PUT(DX&NDX.,&FMT.) = '1' AND DXPOA&NDX. IN ('Y','W')) OR
  (PUT(DX&NDX.,$poaxmpt.)='1' AND PUT(DX&NDX.,&FMT.) = '1') )

 %MEND;
/*Macro to determine if measure format diagnosis is included in any discharge diagnosis code as present on admission.*/
 %MACRO MDXAQ2(FMT);

 (%DO I = 1 %TO &NDX.-1;
  (put(DX&I.,$poaxmpt.)='0' and put(DX&I.,&FMT.) = '1' and DXPOA&I. in ('Y','W')) or
  (put(DX&I.,$poaxmpt.)='1' and put(DX&I.,&FMT.) = '1') or
  %END;
  (put(DX&NDX.,$poaxmpt.)='0' and put(DX&NDX.,&FMT.) = '1' and DXPOA&NDX. in ('Y','W')) or
  (put(DX&NDX.,$poaxmpt.)='1' and put(DX&NDX.,&FMT.) = '1') )

 %MEND;
 /*Macro to compare discharge DRG code against format.*/
 %MACRO MDR(FMT);

 (PUT(PUT(DRG,Z3.),&FMT.) = '1')

 %MEND;

 /*Macro to compare all discharge procedure codes against format.*/
 %MACRO MPR(FMT);

 (%DO I = 1 %TO &NPR.-1;
  (PUT(PR&I.,&FMT.) = '1') OR
  %END;
  (PUT(PR&NPR.,&FMT.) = '1'))

 %MEND;
/*Macro to compare first discharge procedure code against format.*/
 %MACRO MPR1(FMT);

 (PUT(PR1,&FMT.) = '1')

 %MEND;
/*Macro to compare secondary discharge procedure codes against format.*/
 %MACRO MPR2(FMT);

 (%DO I = 2 %TO &NPR.-1;
  (PUT(PR&I.,&FMT.) = '1') OR
  %END;
  (PUT(PR&NPR.,&FMT.) = '1'))

 %MEND;
/*Macro to compare discharge procedure codes against measure format and operating room format and count total.*/
 %MACRO MPRCNT(FMT);

    MPRCNT = 0; 
    %DO I = 1 %TO &NPR.;
       IF PUT(PR&I.,&FMT.) = '1'    AND
          PUT(PR&I.,$ORPROC.) = '1' THEN MPRCNT + 1;
    %END;

 %MEND;
/*Macro to return the first day a measure format procedure was conducted based on PRDAY.*/
 %MACRO MPRDAY(FMT);

    MPRDAY = .;
    %DO I = 1 %TO &NPR.;
       IF PUT(PR&I.,&FMT.) = '1' AND PRDAY&I. GT .Z THEN DO;
          IF MPRDAY LE .Z THEN MPRDAY = PRDAY&I;
          ELSE IF MPRDAY > PRDAY&I. THEN MPRDAY = PRDAY&I;
       END;
    %END;

 %MEND;
/*Macro to count the number of procedures on the discharge that are operating room procedures.*/
%MACRO ORCNT;

    ORCNT = 0;
    %DO I = 1 %TO &NPR.;
       IF(PUT(PR&I.,$ORPROC.) = '1') THEN ORCNT + 1;
    %END;

%MEND;
/*Macro to return first day an operating room procedure was conducted that was not the measure format based on PRDAY.*/
%MACRO ORDAY(FMT);

    ORDAY = .;
    %DO I = 1 %TO &NPR.;
       IF ((PUT(PR&I.,$ORPROC.) = '1')) AND
          PUT(PR&I.,&FMT.)    = '0' THEN DO;
          IF PRDAY&I. GT .Z THEN DO;
             IF ORDAY = . THEN ORDAY = PRDAY&I;
             ELSE IF ORDAY > PRDAY&I. THEN ORDAY = PRDAY&I;
          END;
       END;
    %END;

%MEND;
