*===========+====== Program: PSI17_ALL_FORMATS.SAS ======================== ;
*
* Description:
*     FORMAT LIB FOR STAND ALONE AHRQ PATIENT SAFETY INDICATOR 17
*     NOTE THAT PATIENT SAFETY INDICATOR PSI 17 IS INCLUDED IN PEDIATRIC 
*     QUALITY INDICATOR MODULE (PDI). 
*
*                >>>  AHRQ QI ICD-10 VERSION 6.0.1 <<<
*	               >>> VERSION DATE SEPT, 2016 <<< 
*
*========================================================================= ;
*PATHNAME specifies the location of the PSI17 folder which includes the
          Programs, Macros, and SASdata subfolders;
%LET PATHNAME=c:\Pathname;                        *<==USER MUST modify;

filename CONTROL "&PATHNAME.\PSI17\Programs\PSI17_ALL_CONTROL.SAS"; 

%INCLUDE CONTROL;


proc format library=LIBRARY;

 /* -------------------------------------------------------------- */
 /* --- FORMATS FOR STRATIFIERS ---------------------------------- */
 /* -------------------------------------------------------------- */

 /* --- FORMAT FOR SEX CATEGORY ---------------------------------- */
value SEXCAT
 1 = 'Male'
 2 = 'Female'
  ;

 /* --- FORMAT FOR AGE CATEGORY ---------------------------------- */
value PAGECAT
 1 = "<1"
 2 = "1 TO 2"
 3 = "3 TO 5"
 4 = "6 TO 12"
 5 = "13 TO 17"
 ;

 /* --- FORMAT FOR AGEDAY CATEGORY ------------------------------- */
value AGEDCAT
 0 = "NA"
 1 = "0 TO 28"
 2 = "29 TO 60"
 3 = "61 TO 90"
 4 = "91+"
 ;

 /* --- FORMAT FOR BIRTH WEIGHT CATEGORY ------------------------- */
value BWHTCAT
 0 = "NA"
 1 = "0 TO 499g"
 2 = "500 TO 749g"
 3 = "750 TO 999g"
 4 = "1000 TO 1249g"
 5 = "1250 TO 1499g"
 6 = "1500 TO 1749g"
 7 = "1750 TO 1999g"
 8 = "2000 TO 2499g"
 9 = "2500g or more"
 ;

 /* --- FORMAT FOR RACE CATEGORY --------------------------------- */
value RACECAT
 1 = 'White'
 2 = 'Black'
 3 = 'Hispanic'
 4 = 'Asian and NH/PI'
 5 = 'Amer Indian/AN'
 6 = 'Other'
  ;

 /* --- FORMAT FOR PAYER CATEGORY ---------------------------------- */
value PAYCAT
 1 = 'Medicare'
 2 = 'Medicaid'
 3 = 'Private'
 4 = 'Self Pay'
 5 = 'No Charge'
 6 = 'Other'
  ;

 /* --- FORMAT FOR POPULATION CATEGORY ----------------------------- */
value POPCAT
 1 = '0 to 4'
 2 = '5 to 9'
 3 = '10 to 14'
 4 = '15 to 17'
  ;

/* ---   FORMAT FOR AGE STRATIFIERS ------------------------------ */

value AGEFMT
low - 4 = 1
 5 -  9 = 2
10 - 14 = 3
15 - 17 = 4
18 - 24 = 5
25 - 29 = 6
30 - 34 = 7
35 - 39 = 8
40 - 44 = 9
45 - 49 = 10
50 - 54 = 11
55 - 59 = 12
60 - 64 = 13
65 - 69 = 14
70 - 74 = 15
75 - 79 = 16
80 - 84 = 17
85 - high = 18;

 * -------------------------------------------------------------- ;
 * --- PDI DEFINING FORMATS ------------------------------------- ;
 * -------------------------------------------------------------- ;

/* MS-DRG (V33) TO MDC */;

value MDCF2T
001 = 77
002 = 77
003 = 77
004 = 77
005 = 77
006 = 77
007 = 77
008 = 77
009 = 77
010 = 77
011 = 77
012 = 77
013 = 77
014 = 77   
015 = 77  
016 = 77
017 = 77
020 = 01
021 = 01
022 = 01
023 = 01
024 = 01
025 = 01
026 = 01
027 = 01
028 = 01
029 = 01
030 = 01
031 = 01
032 = 01
033 = 01
034 = 01
035 = 01
036 = 01
037 = 01
038 = 01
039 = 01
040 = 01
041 = 01
042 = 01
052 = 01
053 = 01
054 = 01
055 = 01
056 = 01
057 = 01
058 = 01
059 = 01
060 = 01
061 = 01
062 = 01
063 = 01
064 = 01
065 = 01
066 = 01
067 = 01
068 = 01
069 = 01
070 = 01
071 = 01
072 = 01
073 = 01
074 = 01
075 = 01
076 = 01
077 = 01
078 = 01
079 = 01
080 = 01
081 = 01
082 = 01
083 = 01
084 = 01
085 = 01
086 = 01
087 = 01
088 = 01
089 = 01
090 = 01
091 = 01
092 = 01
093 = 01
094 = 01
095 = 01
096 = 01
097 = 01
098 = 01
099 = 01
100 = 01
101 = 01
102 = 01
103 = 01
113 = 02
114 = 02
115 = 02
116 = 02
117 = 02
121 = 02
122 = 02
123 = 02
124 = 02
125 = 02
129 = 03
130 = 03
131 = 03
132 = 03
133 = 03
134 = 03
135 = 03
136 = 03
137 = 03
138 = 03
139 = 03
146 = 03
147 = 03
148 = 03
149 = 03
150 = 03
151 = 03
152 = 03
153 = 03
154 = 03
155 = 03
156 = 03
157 = 03
158 = 03
159 = 03
163 = 04
164 = 04
165 = 04
166 = 04
167 = 04
168 = 04
175 = 04
176 = 04
177 = 04
178 = 04
179 = 04
180 = 04
181 = 04
182 = 04
183 = 04
184 = 04
185 = 04
186 = 04
187 = 04
188 = 04
189 = 04
190 = 04
191 = 04
192 = 04
193 = 04
194 = 04
195 = 04
196 = 04
197 = 04
198 = 04
199 = 04
200 = 04
201 = 04
202 = 04
203 = 04
204 = 04
205 = 04
206 = 04
207 = 04
208 = 04
215 = 05
216 = 05
217 = 05
218 = 05
219 = 05
220 = 05
221 = 05
222 = 05
223 = 05
224 = 05
225 = 05
226 = 05
227 = 05
228 = 05
229 = 05
230 = 05
231 = 05
232 = 05
233 = 05
234 = 05
235 = 05
236 = 05
237 = 05
238 = 05
239 = 05
240 = 05
241 = 05
242 = 05
243 = 05
244 = 05
245 = 05
246 = 05
247 = 05
248 = 05
249 = 05
250 = 05
251 = 05
252 = 05
253 = 05
254 = 05
255 = 05
256 = 05
257 = 05
258 = 05
259 = 05
260 = 05
261 = 05
262 = 05
263 = 05
264 = 05
265 = 05
266 = 05
267 = 05
280 = 05
281 = 05
282 = 05
283 = 05
284 = 05
285 = 05
286 = 05
287 = 05
288 = 05
289 = 05
290 = 05
291 = 05
292 = 05
293 = 05
294 = 05
295 = 05
296 = 05
297 = 05
298 = 05
299 = 05
300 = 05
301 = 05
302 = 05
303 = 05
304 = 05
305 = 05
306 = 05
307 = 05
308 = 05
309 = 05
310 = 05
311 = 05
312 = 05
313 = 05
314 = 05
315 = 05
316 = 05
326 = 06
327 = 06
328 = 06
329 = 06
330 = 06
331 = 06
332 = 06
333 = 06
334 = 06
335 = 06
336 = 06
337 = 06
338 = 06
339 = 06
340 = 06
341 = 06
342 = 06
343 = 06
344 = 06
345 = 06
346 = 06
347 = 06
348 = 06
349 = 06
350 = 06
351 = 06
352 = 06
353 = 06
354 = 06
355 = 06
356 = 06
357 = 06
358 = 06
368 = 06
369 = 06
370 = 06
371 = 06
372 = 06
373 = 06
374 = 06
375 = 06
376 = 06
377 = 06
378 = 06
379 = 06
380 = 06
381 = 06
382 = 06
383 = 06
384 = 06
385 = 06
386 = 06
387 = 06
388 = 06
389 = 06
390 = 06
391 = 06
392 = 06
393 = 06
394 = 06
395 = 06
405 = 07
406 = 07
407 = 07
408 = 07
409 = 07
410 = 07
411 = 07
412 = 07
413 = 07
414 = 07
415 = 07
416 = 07
417 = 07
418 = 07
419 = 07
420 = 07
421 = 07
422 = 07
423 = 07
424 = 07
425 = 07
432 = 07
433 = 07
434 = 07
435 = 07
436 = 07
437 = 07
438 = 07
439 = 07
440 = 07
441 = 07
442 = 07
443 = 07
444 = 07
445 = 07
446 = 07
453 = 08
454 = 08
455 = 08
456 = 08
457 = 08
458 = 08
459 = 08
460 = 08
461 = 08
462 = 08
463 = 08
464 = 08
465 = 08
466 = 08
467 = 08
468 = 08
469 = 08
470 = 08
471 = 08
472 = 08
473 = 08
474 = 08
475 = 08
476 = 08
477 = 08
478 = 08
479 = 08
480 = 08
481 = 08
482 = 08
483 = 08
484 = 08
485 = 08
486 = 08
487 = 08
488 = 08
489 = 08
490 = 08
491 = 08
492 = 08
493 = 08
494 = 08
495 = 08
496 = 08
497 = 08
498 = 08
499 = 08
500 = 08
501 = 08
502 = 08
503 = 08
504 = 08
505 = 08
506 = 08
507 = 08
508 = 08
509 = 08
510 = 08
511 = 08
512 = 08
513 = 08
514 = 08
515 = 08
516 = 08
517 = 08
518 = 08
519 = 08
520 = 08
533 = 08
534 = 08
535 = 08
536 = 08
537 = 08
538 = 08
539 = 08
540 = 08
541 = 08
542 = 08
543 = 08
544 = 08
545 = 08
546 = 08
547 = 08
548 = 08
549 = 08
550 = 08
551 = 08
552 = 08
553 = 08
554 = 08
555 = 08
556 = 08
557 = 08
558 = 08
559 = 08
560 = 08
561 = 08
562 = 08
563 = 08
564 = 08
565 = 08
566 = 08
570 = 09
571 = 09
572 = 09
573 = 09
574 = 09
575 = 09
576 = 09
577 = 09
578 = 09
579 = 09
580 = 09
581 = 09
582 = 09
583 = 09
584 = 09
585 = 09
592 = 09
593 = 09
594 = 09
595 = 09
596 = 09
597 = 09
598 = 09
599 = 09
600 = 09
601 = 09
602 = 09
603 = 09
604 = 09
605 = 09
606 = 09
607 = 09
614 = 10
615 = 10
616 = 10
617 = 10
618 = 10
619 = 10
620 = 10
621 = 10
622 = 10
623 = 10
624 = 10
625 = 10
626 = 10
627 = 10
628 = 10
629 = 10
630 = 10
637 = 10
638 = 10
639 = 10
640 = 10
641 = 10
642 = 10
643 = 10
644 = 10
645 = 10
652 = 11
653 = 11
654 = 11
655 = 11
656 = 11
657 = 11
658 = 11
659 = 11
660 = 11
661 = 11
662 = 11
663 = 11
664 = 11
665 = 11
666 = 11
667 = 11
668 = 11
669 = 11
670 = 11
671 = 11
672 = 11
673 = 11
674 = 11
675 = 11
682 = 11
683 = 11
684 = 11
685 = 11
686 = 11
687 = 11
688 = 11
689 = 11
690 = 11
691 = 11
692 = 11
693 = 11
694 = 11
695 = 11
696 = 11
697 = 11
698 = 11
699 = 11
700 = 11
707 = 12
708 = 12
709 = 12
710 = 12
711 = 12
712 = 12
713 = 12
714 = 12
715 = 12
716 = 12
717 = 12
718 = 12
722 = 12
723 = 12
724 = 12
725 = 12
726 = 12
727 = 12
728 = 12
729 = 12
730 = 12
734 = 13
735 = 13
736 = 13
737 = 13
738 = 13
739 = 13
740 = 13
741 = 13
742 = 13
743 = 13
744 = 13
745 = 13
746 = 13
747 = 13
748 = 13
749 = 13
750 = 13
754 = 13
755 = 13
756 = 13
757 = 13
758 = 13
759 = 13
760 = 13
761 = 13
765 = 14
766 = 14
767 = 14
768 = 14
769 = 14
770 = 14
774 = 14
775 = 14
776 = 14
777 = 14
778 = 14
779 = 14
780 = 14
781 = 14
782 = 14
789 = 15
790 = 15
791 = 15
792 = 15
793 = 15
794 = 15
795 = 15
799 = 16
800 = 16
801 = 16
802 = 16
803 = 16
804 = 16
808 = 16
809 = 16
810 = 16
811 = 16
812 = 16
813 = 16
814 = 16
815 = 16
816 = 16
820 = 17
821 = 17
822 = 17
823 = 17
824 = 17
825 = 17
826 = 17
827 = 17
828 = 17
829 = 17
830 = 17
834 = 17
835 = 17
836 = 17
837 = 17
838 = 17
839 = 17
840 = 17
841 = 17
842 = 17
843 = 17
844 = 17
845 = 17
846 = 17
847 = 17
848 = 17
849 = 17
853 = 18
854 = 18
855 = 18
856 = 18
857 = 18
858 = 18
862 = 18
863 = 18
864 = 18
865 = 18
866 = 18
867 = 18
868 = 18
869 = 18
870 = 18
871 = 18
872 = 18
876 = 19
880 = 19
881 = 19
882 = 19
883 = 19
884 = 19
885 = 19
886 = 19
887 = 19
894 = 20
895 = 20
896 = 20
897 = 20
901 = 21
902 = 21
903 = 21
904 = 21
905 = 21
906 = 21
907 = 21
908 = 21
909 = 21
913 = 21
914 = 21
915 = 21
916 = 21
917 = 21
918 = 21
919 = 21
920 = 21
921 = 21
922 = 21
923 = 21
927 = 22
928 = 22
929 = 22
933 = 22
934 = 22
935 = 22
939 = 23
940 = 23
941 = 23
945 = 23
946 = 23
947 = 23
948 = 23
949 = 23
950 = 23
951 = 23
955 = 24
956 = 24
957 = 24
958 = 24
959 = 24
963 = 24
964 = 24
965 = 24
969 = 25
970 = 25
974 = 25
975 = 25
976 = 25
977 = 25
981 = 88
982 = 88
983 = 88
984 = 88
985 = 88
986 = 88
987 = 88
988 = 88
989 = 88
998 = 88
999 = 88
OTHER  = 99 ;


/* ---------------------------------------------------------------- */
 /* LOW BIRTH WEIGHT                                                 */
 /* ---------------------------------------------------------------- */

 /* ICD-10-CM DIAGNOSIS CODES: */

value $LW500G
"P0501"  =  "1"  /* Newborn light for gestational age, less than 500 grams */
"P0511"  =  "1"  /* Newborn small for gestational age, less than 500 grams */
"P0701"  =  "1"  /* Extremely low birth weight newborn, less than 500 grams */
OTHER = "0" ;

value $LW750G
"P0502"  =  "1"  /* Newborn light for gestational age, 500-749 grams */
"P0512"  =  "1"  /* Newborn small for gestational age, 500-749 grams */
"P0702"  =  "1"  /* Extremely low birth weight newborn, 500-749 grams */
OTHER   = "0";

value $LW1000G
"P0503"  =  "1"  /* Newborn light for gestational age, 750-999 grams */
"P0513"  =  "1"  /* Newborn small for gestational age, 750-999 grams */
"P0703"  =  "1"  /* Extremely low birth weight newborn, 750-999 grams */
OTHER   = "0";

value $LW1250G
"P0504"  =  "1"  /* Newborn light for gestational age, 1000-1249 grams */
"P0514"  =  "1"  /* Newborn small for gestational age, 1000-1249 grams */
"P0714"  =  "1"  /* Other low birth weight newborn, 1000-1249 grams */
OTHER   = "0";

value $LW1500G
"P0505"  =  "1"  /* Newborn light for gestational age, 1250-1499 grams */
"P0515"  =  "1"  /* Newborn small for gestational age, 1250-1499 grams */
"P0715"  =  "1"  /* Other low birth weight newborn, 1250-1499 grams */
OTHER   = "0";

value $LW1750G
"P0506"  =  "1"  /* Newborn light for gestational age, 1500-1749 grams */
"P0516"  =  "1"  /* Newborn small for gestational age, 1500-1749 grams */
"P0716"  =  "1"  /* Other low birth weight newborn, 1500-1749 grams */
OTHER   = "0";

value $LW2000G
"P0507"  =  "1"  /* Newborn light for gestational age, 1750-1999 grams */
"P0517"  =  "1"  /* Newborn small for gestational age, 1750-1999 grams */
"P0717"  =  "1"  /* Other low birth weight newborn, 1750-1999 grams */
OTHER   = "0";

value $LW2500G
"P0508"  =  "1"  /* Newborn light for gestational age, 2000-2499 grams */
"P0518"  =  "1"  /* Newborn small for gestational age, 2000-2499 grams */
"P0718"  =  "1"  /* Other low birth weight newborn, 2000-2499 grams */
OTHER   = "0";


 /* BIRTH INJURIES */
 /* ICD-10-CM DIAGNOSIS CODES: */
 
value $BIRTHID
"P100"  =  "1"  /* Subdural hemorrhage due to birth injury */
"P101"  =  "1"  /* Cerebral hemorrhage due to birth injury */
"P102"  =  "1"  /* Intraventricular hemorrhage due to birth injury */
"P103"  =  "1"  /* Subarachnoid hemorrhage due to birth injury */
"P104"  =  "1"  /* Tentorial tear due to birth injury */
"P108"  =  "1"  /* Other intracranial lacerations and hemorrhages due to birth injury */
"P109"  =  "1"  /* Unspecified intracranial laceration and hemorrhage due to birth injury */
"P110"  =  "1"  /* Cerebral edema due to birth injury */
"P111"  =  "1"  /* Other specified brain damage due to birth injury */
"P112"  =  "1"  /* Unspecified brain damage due to birth injury */
"P113"  =  "1"  /* Birth injury to facial nerve */
"P114"  =  "1"  /* Birth injury to other cranial nerves */
"P115"  =  "1"  /* Birth injury to spine and spinal cord */
"P119"  =  "1"  /* Birth injury to central nervous system, unspecified */
"P122"  =  "1"  /* Epicranial subaponeurotic hemorrhage due to birth injury */
"P130"  =  "1"  /* Fracture of skull due to birth injury */
"P131"  =  "1"  /* Other birth injuries to skull */
"P132"  =  "1"  /* Birth injury to femur */
"P133"  =  "1"  /* Birth injury to other long bones */
"P138"  =  "1"  /* Birth injuries to other parts of skeleton */
"P139"  =  "1"  /* Birth injury to skeleton, unspecified */
"P142"  =  "1"  /* Phrenic nerve paralysis due to birth injury */
"P148"  =  "1"  /* Birth injuries to other parts of peripheral nervous system */
"P149"  =  "1"  /* Birth injury to peripheral nervous system, unspecified */
"P150"  =  "1"  /* Birth injury to liver */
"P151"  =  "1"  /* Birth injury to spleen */
"P152"  =  "1"  /* Sternomastoid injury due to birth injury */
"P153"  =  "1"  /* Birth injury to eye */
"P154"  =  "1"  /* Birth injury to face */
"P155"  =  "1"  /* Birth injury to external genitalia */
"P156"  =  "1"  /* Subcutaneous fat necrosis due to birth injury */
"P158"  =  "1"  /* Other specified birth injuries */
OTHER   = 0 ;

 /* BIRTH TRAUMA */
 /* ICD-10-CM DIAGNOSIS CODES */

value $LIVEBND
"Z3800"  =  "1"  /* Single liveborn infant, delivered vaginally */
"Z3801"  =  "1"  /* Single liveborn infant, delivered by cesarean */
"Z3830"  =  "1"  /* Twin liveborn infant, delivered vaginally */
"Z3831"  =  "1"  /* Twin liveborn infant, delivered by cesarean */
"Z3861"  =  "1"  /* Triplet liveborn infant, delivered vaginally */
"Z3862"  =  "1"  /* Triplet liveborn infant, delivered by cesarean */
"Z3863"  =  "1"  /* Quadruplet liveborn infant, delivered vaginally */
"Z3864"  =  "1"  /* Quadruplet liveborn infant, delivered by cesarean */
"Z3865"  =  "1"  /* Quintuplet liveborn infant, delivered vaginally */
"Z3866"  =  "1"  /* Quintuplet liveborn infant, delivered by cesarean */
"Z3868"  =  "1"  /* Other multiple liveborn infant, delivered vaginally */
"Z3869"  =  "1"  /* Other multiple liveborn infant, delivered by cesarean */
OTHER   = 0 ;

/* value $V29D per UCD - There are no acceptable ICD-10-CM codes but this format may be used in the future */

value $LIVEB2D
"Z381"  =  "1"  /* Single liveborn infant, born outside hospital */
"Z384"  =  "1"  /* Twin liveborn infant, born outside hospital */
"Z387"  =  "1"  /* Other multiple liveborn infant, born outside hospital */
OTHER   = 0 ;

 
 /* EXCLUDE: PRETERM INFANT */
 /* ICD-10-CM DIAGNOSIS CODES: */

value $PRETEID
"P0700"  =  "1"  /* Extremely low birth weight newborn, unspecified weight */
"P0701"  =  "1"  /* Extremely low birth weight newborn, less than 500 grams */
"P0702"  =  "1"  /* Extremely low birth weight newborn, 500-749 grams */
"P0703"  =  "1"  /* Extremely low birth weight newborn, 750-999 grams */
"P0710"  =  "1"  /* Other low birth weight newborn, unspecified weight */
"P0714"  =  "1"  /* Other low birth weight newborn, 1000-1249 grams */
"P0715"  =  "1"  /* Other low birth weight newborn, 1250-1499 grams */
"P0716"  =  "1"  /* Other low birth weight newborn, 1500-1749 grams */
"P0717"  =  "1"  /* Other low birth weight newborn, 1750-1999 grams */
OTHER   = "0" ;

 /* EXCLUDE: OSTEOGENESIS IMPERFECTA */;
 /* ICD-10-CM DIAGNOSIS CODES: */

value $OSTEOID
"Q780"  =  "1"  /* Osteogenesis imperfecta */
OTHER   = "0" ;


run;
